#! /bin/bash

PACKAGE_NAME="printer-driver-bisheng-tec-b-452-r"
PACKAGE_VERSION="2.0.1"
PRINTER_NAME=( "TEC B-452-R" "TEC B-462-R" "TEC B-852-R" "TEC B-EP2DL-G" "TEC B-EP4DL-G" "TEC B-EV4 -203 dpi-" "TEC B-EV4 -300 dpi-" "TEC B-SA4T -203 dpi-" "TEC B-SA4T -300 dpi-" "TEC B-SA4T-CN -203 dpi-" "TEC B-SA4T-CN -300 dpi-" "TEC B-SV4" "TEC B-SX4T -203 dpi-" "TEC B-SX4T-CN -203 dpi-" "TEC B-SX5T -305 dpi-" "TEC B-SX5T-CN -305 dpi-" "TEC B-SX6T -305 dpi-" "TEC B-SX8T -305 dpi-" "TOSHIBA B-EX4T1 -203 dpi-" "TOSHIBA B-EX4T1 -305 dpi-" "TOSHIBA B-EX4T2 -203 dpi-" "TOSHIBA B-EX4T2 -300 dpi-" "TOSHIBA B-EX4T2 -600 dpi-" "TOSHIBA B-EX4T3 -600 dpi-" "TOSHIBA B-EX6T1 -203 dpi-" "TOSHIBA B-EX6T1 -305 dpi-" "TOSHIBA B-EX6T3 -203 dpi-" "TOSHIBA B-EX6T3 -305 dpi-" "TOSHIBA B-FP3D -203 dpi-" "TOSHIBA B-FV4 -203 dpi-" "TOSHIBA B-FV4 -300 dpi-" "TOSHIBA DB-EA4D" )

CONTAINER_PATH="$HOME/.deepinwine/$PACKAGE_NAME"
OPT_PATH="/opt/deepinwine/printer_drv/$PACKAGE_NAME"
WINEBIN="bisheng"
REGDIR="reg"
FILEDIR="files"

PRINTER_C=$1
found=0
for name in "${PRINTER_NAME[@]}"; do
    if [ "$PRINTER_C" = "$name" ]; then
        found=1
        break
    fi
done

if [ $found -eq 0 ]; then
    echo "printer $PRINTER_C not found"
    exit 0
fi

if [ -z "$PACKAGE_NAME" -o ! -d "$OPT_PATH" ]; then
    exit 1
fi

if [ -d "$CONTAINER_PATH" ]; then
    # compare version
    if [ ! -f "$CONTAINER_PATH/VERSION" ] || [ "$(cat "$CONTAINER_PATH/VERSION")" != "$PACKAGE_VERSION" ]; then
        rm -rf "$CONTAINER_PATH"
    fi
fi

WININI="$CONTAINER_PATH/drive_c/windows/win.ini"
if [ -f  $WININI ]; then
    grep -q "^$PRINTER_C=winerp.drv,USB" "$WININI" && exit 0
fi

if [ -d "$OPT_PATH/$REGDIR" ]; then
    find "$OPT_PATH/$REGDIR" -type f -regex ".*\.reg" | while read file; do
        WINEPREFIX=$CONTAINER_PATH $WINEBIN regedit "$file"
    done
fi

if [ -d "$OPT_PATH/$FILEDIR" ]; then
    find "$OPT_PATH/$FILEDIR" -not -type d | while read file; do
        path="$CONTAINER_PATH/drive_c/${file#*$FILEDIR/}"
        dir="${path%/*}"
        mkdir -p "$dir"
        cp -d "$file" "$path"
    done
fi

if [ -f "$WININI" ]; then
    grep -q "^\[devices\]" "$WININI" || sed -i -e "$ a [devices]" "$WININI"
    grep -q "^\[PrinterPorts\]" "$WININI" || sed -i -e "$ a [PrinterPorts]" "$WININI"
    sed -i -e "/^\[devices\]/a $PRINTER_C=winerp.drv,USB" "$WININI"
    sed -i -e "/^\[PrinterPorts\]/a $PRINTER_C=winerp.drv,USB,15,45" "$WININI"
fi

WINESERVER_RUNNING=1
WINESERVER_FINDNUM=0
while [ $WINESERVER_RUNNING -eq 1 ]
do
        WINESERVER_PATH=`ps -aux|grep wineserver|grep -v grep`
        if [ "$WINESERVER_PATH" = "" ] || [ $WINESERVER_FINDNUM -eq 3 ]; then
                WINESERVER_RUNNING=0
        else
                let WINESERVER_FINDNUM+=1
                sleep 1
        fi
done

echo "$PACKAGE_VERSION" > "$CONTAINER_PATH/VERSION"
echo "$PRINTER_NAME" > "$CONTAINER_PATH/name.log"
